<?
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: crearimagenbasica_eng.php (Comandos)
//	Idioma: Ingles
//________________________________________________________________________________________________________
	$TbMsg=array();
	$TbMsg[0]='Generation of base image  <br> (experimental)' ;
	$TbMsg[1]='Computer features';
        $TbMsg[2]='Name';
        $TbMsg[3]='IP Address';
        $TbMsg[4]='MAC Address';
        $TbMsg[5]='Hardware profile';
        $TbMsg[6]='Data to provide';
	$TbMsg[7]='Disc';
	$TbMsg[8]='Par';
	$TbMsg[9]='O.S. Name';
	$TbMsg[10]='Image / Repositorio';
	$TbMsg[11]='Repositorio';
	$TbMsg[12]='Additional Options';
	$TbMsg[13]='Borrar la Imagen Previamente';	
	$TbMsg[14]='Copiar Imagen en cache';
	$TbMsg[15]='Borrarla previamente de la cache';			
	$TbMsg[16]='No borrar archivos en destino';			
?>
