<?
//________________________________________________________________________________________________________
//
//	Fitxer d'idiomes php: propiedades_ordenadores_cat.php 
//	Idioma: Català 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="Sense Opció";
$TbMsg[1]="Afegir";
$TbMsg[2]="Modificar";
$TbMsg[3]="Eliminar";
$TbMsg[4]="Gestió Usuaris";
$TbMsg[5]="Usuari";
$TbMsg[6]="Password";
$TbMsg[7]="Nom complet";
$TbMsg[8]="E-mail";
$TbMsg[9]="Unitat organitzativa";
$TbMsg[10]="Idioma";
$TbMsg[11]="SuperAdministrador ";
$TbMsg[12]="Administrador";
$TbMsg[13]="Operador";
$TbMsg[14]="Per realitzar canvis en aquest usuari<br>";
$TbMsg[15]="creat en el procés d'instal·lació,<br><br>";
$TbMsg[16]="
premi aquí<br>";
$TbMsg[17]="http://opengnsys.es/wiki/ModificarUsuarios";
?>