<?php
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: configurar_esp.php (Comandos)
//	Idioma: Espa�l 
//________________________________________________________________________________________________________
	if (empty ($TbMsg)) $TbMsg=array();
	$TbMsg[0]='Centros';
	$TbMsg[1]='Grupo de aulas';
	$TbMsg[2]='Aulas';
	$TbMsg[3]='Grupo de ordenadores';
	$TbMsg[4]='Ordenadores';
	$TbMsg[5]='Particionar y Formatear';
	$TbMsg[6]='Ámbito';
	$TbMsg[7]='Partición oculta';
	$TbMsg[8]='Par';
	$TbMsg[9]='';
	$TbMsg[10]='';
	$TbMsg[11]='';
	$TbMsg[12]='Operación';
	$TbMsg[13]='Sin acción';
	$TbMsg[14]='Formatear';
	$TbMsg[15]='Ocultar';
	$TbMsg[16]='Mostrar';
	$TbMsg[17]=' Espacio libre !!';
	
	$TbMsg[18]="DESAGRUPAR SEGÚN VALORES DISTINTOS DE:";
	$TbMsg[19]="Datos a suministrar";

	// Cabeceras de tabla de configuración
	$TbMsg[20]='Partición';
	$TbMsg[21]='S.O. Instalado';
	$TbMsg[22]='Tamaño';
	$TbMsg[23]='Datos de configuration';
	$TbMsg[24]='Tipo';
	$TbMsg[25]='Imagen';
	$TbMsg[26]='Perfil Software';
	$TbMsg[27]='S.F.';
	$TbMsg[28]='Ninguno';
	$TbMsg[29]='Desconocido';
	// Desagrupamiento
	$TbMsg[30]='Sistema de Ficheros';
	$TbMsg[31]='Nombre del S.O.';
	$TbMsg[32]='Tamaño de partición';
	$TbMsg[33]='Nombre de la Imagen ';
	$TbMsg[34]='Perfil software';
?>
