//________________________________________________________________________________________________________
//	
//	Fichero de idiomas javascript: propiedades_ordenadores_esp.js 
//	Idioma: Español 
//________________________________________________________________________________________________________
TbMsg=new Array;
TbMsg[0]="Debe introducir un nombre para este ordenador";
TbMsg[1]="Debe introducir una dirección IP";
TbMsg[2]="Debe introducir a una dirección MAC";
TbMsg[3]="";
TbMsg[4]="";
TbMsg[5]="Debe elegir un repositorio por defecto";
TbMsg[6]="Deben introducirse datos de validación: página de login y página de validación";
