//________________________________________________________________________________________________________
//
//	Fichero de idiomas javascripts: configurar_eng.js 
//	Idioma: Ingés 
//________________________________________________________________________________________________________
TbMsg=new Array;
TbMsg[0]="WARNING.- There are partitions with the same number, you must select another or remove it  clicking in the last column";
TbMsg[1]="WARNING.- The number of the partition must be greater than zero";
TbMsg[2]="El tipo de partición no se ha especificado";
TbMsg[3]="WARNING.- The size of the partition must be greater than zero";
TbMsg[4]="ATENCION: Se va a eliminar esta partición ¿ Esta seguro ?";
TbMsg[5]="Debe especificar el tipo de sistema de ficheros si desea formatear la particion";
TbMsg[6]="La CACHE solo puede definirse en la particion 4";
TbMsg[7]="El número maximo de particiones es 4";

