//____________________________________________________________________________
//	
//	Fichero de idiomas javascript: ejecutarprocedimientos_esp.js 
//	Idioma: Español 
//____________________________________________________________________________
TbMsg=new Array;
TbMsg[0]="ATENCIÓN.- El Procedimiento será ejecutado aplicándolo a este ámbito. ¿ Está seguro ?";
TbMsg[1]="El Procedimiento ha sido gestionado correctamente para este ámbito";
TbMsg[4]="\t!!!!!     ATENCIÓ     !!!!! \nHa seleccionat Unicast en diversos ordinadors,\nLa transferència pot demorar en el temps";