<?php
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: informacion_repositorio_esp.php 
//	Idioma: Español 
//________________________________________________________________________________________________________
	if (empty ($TbMsg)) $TbMsg=array();
	$TbMsg[0]='Repositorios';
	$TbMsg[1]='Información sobre Repositorios';
	$TbMsg[2]='Repositorio';
	$TbMsg[3]='Información Repositorio';
	$TbMsg[4]='Comentarios';
	$TbMsg[5]='Imágenes alojadas';	
	$TbMsg["IMGTYPE1"]='monol&iacute;tica';		
	$TbMsg["IMGTYPE2"]='sincronizada b&iacute;sica';		
	$TbMsg["IMGTYPE3"]='sincronizada incremental';		
	$TbMsg[6]='Ordenadores asigandos';		
?>

