<?php
//______________________________________________________
//
//	Fichero de idiomas php: acercade_eng.php 
//	Idioma: Ingles
//______________________________________________________
// Si ya existe TbMsg, solo agregamos lo nuevo
if(!isset($TbMsg)){
	$TbMsg=array();
}

$TbMsg["TITLE"]='Free and open-source application for deployment and management of operating systems.';
$TbMsg["DESCRIPTION"]='OpenGnSys <em> (Open Genesis)</em> Project brings together the combined efforts of several Spanish Public Universities. OpenGnSys provide a number of free and open tools for managing and deploying computers. These tools supplies a complete, versatile and intuitive sytem. This system allows the arrangement, installation and deployment of different operating systems.';
$TbMsg["LICENSE"]='OpenGnSys is a Free Software project. As such, all code is licensed under ';
$TbMsg["LINK"]='Web project:';
$TbMsg["CHANGE"]='Changes in: ';
$TbMsg["MANUAL"]='Manual OpenGnSys ';


?>

