<?
//________________________________________________________________________________________________________
//
//	Fichero de idiomas php: propiedades_ordenadores_esp.php 
//	Idioma: Español 
//________________________________________________________________________________________________________
$TbMsg=array();
$TbMsg[0]="Sin Opción";
$TbMsg[1]="Insertar";
$TbMsg[2]="Modificar";
$TbMsg[3]="Eliminar";
$TbMsg[4]="Gestión Usuarios";
$TbMsg[5]="Usuario";
$TbMsg[6]="Password";
$TbMsg[7]="Nombre completo";
$TbMsg[8]="E-mail";
$TbMsg[9]="Unidad organizativa";
$TbMsg[10]="Idioma ";
$TbMsg[11]="SuperAdministrador ";
$TbMsg[12]="Administrador";
$TbMsg[13]="Operador";
$TbMsg[14]="Para realizar cambios en este usuario<br>";
$TbMsg[15]="creado en el proceso de instalación,<br><br>";
$TbMsg[16]="pulse aquí<br>";
$TbMsg[17]="http://opengnsys.es/wiki/ModificarUsuarios";
?>