//____________________________________________________________________________
//	
//	Fichero de idiomas javascript: propiedades_repositorios_eng.js
//	Idioma: Ingles
//____________________________________________________________________________
TbMsg=new Array;
TbMsg[0]="El nombre del repositorio sólo puede contener caracteres alfanuméricos";
TbMsg[1]="Debe introducir una dirección IP";
TbMsg[2]="ATENCIÓN: Hay imágenes alojadas por este repositorio. ¿Está seguro de querer eliminarlo ?";
TbMsg[3]="Debe introducir un puerto de comunicaciones para los clientes";
TbMsg[4]="Los comentarios sólo pueden contener caracteres alfanuméricos";
